@@ -18,9 +18,9 @@ class DataDownloader():
         self.context = context
 
     async def fetch_image_ids(self, query_params: Optional[str] = '') -> List[str]:
-        async with loop.get(f'api/{self.context.organization}/projects/{self.context.project}/data?{query_params}') as response:
-            assert response.status == 200, response
-            return (await response.json())['image_ids']
+        response = await loop.get(f'/{self.context.organization}/projects/{self.context.project}/data?{query_params}')
+        assert response.status_code == 200, response
+        return (response.json())['image_ids']
 
     async def download_images_data(self, ids: List[str]) -> List[dict]:
         return await downloads.download_images_data(self.context.organization, self.context.project, ids)
